@@ -7,19 +7,17 @@
 #include <albert/indexqueryhandler.h>
 class QNetworkReply;
 
-
-class Plugin : public albert::util::ExtensionPlugin,
-               public albert::util::IndexQueryHandler
+class Plugin : public albert::ExtensionPlugin, public albert::IndexQueryHandler
 {
     ALBERT_PLUGIN
 
 public:
-
     Plugin();
     ~Plugin();
+    void initialize() override;
 
     void updateIndexItems() override;
-    QWidget* buildConfigWidget() override;
+    QWidget *buildConfigWidget() override;
 
     void updateDocsetList();
     const std::vector<Docset> &docsets() const;
@@ -32,21 +30,20 @@ public:
     static Plugin *instance();
 
 private:
-
     void debug(const QString &);
     void error(const QString &, QWidget *modal_parent = nullptr);
     std::filesystem::path docsetsLocation() const;
+    std::filesystem::path customDocsetsLocation() const;
     std::filesystem::path iconsLocation() const;
 
     std::vector<Docset> docsets_;
     QNetworkReply *download_ = nullptr;
     static Plugin *instance_;
-    albert::util::BackgroundExecutor<std::shared_ptr<std::vector<albert::util::IndexItem>>> indexer;
+    albert::BackgroundExecutor<std::vector<albert::IndexItem>> indexer;
 
 signals:
 
     void docsetsChanged();
     void downloadStateChanged();
-    void statusInfo(const QString&);
-
+    void statusInfo(const QString &);
 };
