@@ -4,7 +4,7 @@
 #include <albert/globalqueryhandler.h>
 #include <albert/extensionplugin.h>
 
-class Plugin : public albert::util::ExtensionPlugin,
+class Plugin : public albert::ExtensionPlugin,
                public albert::GlobalQueryHandler
 {
     ALBERT_PLUGIN
@@ -12,7 +12,7 @@ class Plugin : public albert::util::ExtensionPlugin,
 public:
 
     Plugin();
-    std::vector<albert::RankItem> handleGlobalQuery(const albert::Query &) override;
+    std::vector<albert::RankItem> rankItems(albert::QueryContext &) override;
 
 private:
 
