@@ -2,11 +2,10 @@
 
 #include "indexqueryhandler.h"
 #include "itemindex.h"
-#include "query.h"
+#include "querycontext.h"
 #include <memory>
 #include <mutex>
 #include <shared_mutex>
-using namespace albert::util;
 using namespace albert;
 using namespace std;
 
@@ -28,11 +27,11 @@ void IndexQueryHandler::setIndexItems(vector<IndexItem> &&index_items)
         d->index->setItems(::move(index_items));
 }
 
-vector<RankItem> IndexQueryHandler::handleGlobalQuery(const Query &query)
+vector<RankItem> IndexQueryHandler::rankItems(QueryContext &ctx)
 {
     shared_lock l(d->index_mutex);
     if (d->index)
-        return d->index->search(query.string(), query.isValid());
+        return d->index->search(ctx.query(), [&ctx] { return ctx.isValid(); });
     return {};
 }
 
